@@ -1,7 +1,16 @@
 // This file must follow ES5
 (function () {
-    function GeocoderFieldWrap(html, _id, geocoder, translations, params) {
+    function GeocoderFieldWrap(html, geocoder, translations, params) {
         this.html = html;
+
+        // In Wagtail < 7.1 argument 2 was id
+        // TODO: Remove when Wagtail 6 is EOL
+        if (arguments[1] === "__ID__") {
+            geocoder= arguments[2]
+            translations = arguments[3]
+            params = arguments[4]
+        }
+
         this.geocoder = geocoder;
         this.translations = translations;
         this.params = params;
@@ -19,6 +28,8 @@
         var fieldByGeocoder = {
             nominatim: NominatimGeocoderField,
             google_maps: GoogleMapsGeocoderField,
+            google_maps_places: GoogleMapsGeocoderPlacesField,
+            google_maps_places_new: GoogleMapsGeocoderPlacesNewField,
             mapbox: MapboxGeocoderField,
         };
 
